
import rendezvous.*;

/**
 * Serverové vlákno
 * @author Miroslav Hendrych
 */
public class Server extends Thread {
    private class EntryPlus implements IEntry {
        public Object entry(Object params) {
            plus++;
            int hodnota = ((Integer)params).intValue();
            return hodnota + 1;
        }

    }

    private class EntryMinus implements IEntry {
        public Object entry(Object params) {
            minus++;
            int hodnota = ((Integer)params).intValue();
            return hodnota - 1;
        }

    }

    private class EntryStop implements IEntry {
        public Object entry(Object params) {
            running = false;
            return null;
        }

    }

    private int plus = 0;
    private int minus = 0;
    private boolean running = true;
    private RendezVous rendezvous;
    private int serverNo;
    private long mainID;

    public Server(int serverNo, RendezVous rendezvous) {
        mainID = Thread.currentThread().getId();
        this.rendezvous = rendezvous;
        this.serverNo = serverNo;
        createEntry();
    }

    private void createEntry() {
        long myId = this.getId();
        rendezvous.registerServer(myId);
        rendezvous.registerEntry(myId, "plus", new EntryPlus());
        rendezvous.registerEntry(myId, "minus", new EntryMinus());
        rendezvous.registerEntry(myId, "stop", new EntryStop());
    }

    public void printStats() {
        System.out.println("Server "+serverNo+":  plus = "+plus+"  minus = "+minus);
    }


    @Override
    public void run() {
        while (running) {
            rendezvous.makeAccept();
        }
        rendezvous.unregisterServer();
    }

}
