
import java.util.HashMap;
import rendezvous.*;

/**
 * Rendez-vous server
 * @author Miroslav Hendrych
 */
public class Server extends Thread {
    private class EntryPlus implements IEntry {
        public Object entry(Object params) {
            hodnota ++;
            return 1;
        }

    }

    private class EntryMinus implements IEntry {
        public Object entry(Object params) {
            hodnota--;
            return 1;
        }

    }

    private class EntryHodnota implements IEntry {
        public Object entry(Object params) {
            return hodnota;
        }
    }

    private class EntryPlusCondition implements IAcceptCondition {
        public boolean isAcceptable() {
            return hodnota < Main.stred + Main.interval;
        }
    }

    private class EntryMinusCondition implements IAcceptCondition {
        public boolean isAcceptable() {
            return hodnota > Main.stred - Main.interval;
        }
    }

    private RendezVous rendezvous;
    private int hodnota = Main.stred;

    public Server(RendezVous rendezvous) {
        this.rendezvous = rendezvous;
        createEntry();
    }

    private void createEntry() {
        Long id = this.getId();
        rendezvous.registerServer(id);
        rendezvous.registerEntry(id, "plus", new EntryPlus());
        rendezvous.registerEntry(id, "minus", new EntryMinus());
        rendezvous.registerEntry(id, "hodnota", new EntryHodnota());
    }

    @Override
    public void run() {
        HashMap<String, IAcceptCondition> accept = new HashMap<String, IAcceptCondition>();
        accept.put("plus", new EntryPlusCondition());
        accept.put("minus", new EntryMinusCondition());
        while (rendezvous.makeAccept(accept, 5000)) {
            rendezvous.makeAccept(new String[] {"hodnota"});
        }
        rendezvous.unregisterServer();
    }

}
